@@ -1,4 +1,4 @@
-{-# LANGUAGE PatternGuards #-}
+{-# LANGUAGE CPP, PatternGuards #-}
 
 -----------------------------------------------------------------------------
 -- |
@@ -16,8 +16,10 @@
 
 module Plugins.Monitors.CoreCommon where
 
+#if __GLASGOW_HASKELL__ < 800
 import Control.Applicative
-import Control.Monad
+#endif
+
 import Data.Char hiding (Space)
 import Data.Function
 import Data.List
@@ -29,7 +31,7 @@ checkedDataRetrieval :: (Ord a, Num a)
                      => String -> [[String]] -> Maybe (String, String -> Int)
                      -> (Double -> a) -> (a -> String) -> Monitor String
 checkedDataRetrieval msg paths lbl trans fmt =
-  liftM (fromMaybe msg . listToMaybe . catMaybes) $
+  fmap (fromMaybe msg . listToMaybe . catMaybes) $
     mapM (\p -> retrieveData p lbl trans fmt) paths
 
 retrieveData :: (Ord a, Num a)
@@ -127,7 +129,7 @@ findFilesAndLabel path lbl  =  catMaybes
 -- | Function to read the contents of the given file(s)
 readFiles :: (String, Either Int (String, String -> Int))
           -> Monitor (Int, String)
-readFiles (fval, flbl) = (,) <$> either return (\(f, ex) -> liftM ex
+readFiles (fval, flbl) = (,) <$> either return (\(f, ex) -> fmap ex
                                                             $ io $ readFile f) flbl
                              <*> io (readFile fval)
 
