@@ -2,7 +2,7 @@
 -----------------------------------------------------------------------------
 -- |
 -- Module      :  Xmobar
--- Copyright   :  (c) 2011, 2012, 2013, 2014, 2015 Jose Antonio Ortega Ruiz
+-- Copyright   :  (c) 2011, 2012, 2013, 2014, 2015, 2017 Jose Antonio Ortega Ruiz
 --                (c) 2007 Andrea Rossato
 -- License     :  BSD-style (see LICENSE)
 --
@@ -106,8 +106,8 @@ startLoop xcfg@(XConf _ _ w _ _ _) sig vs = do
 #endif
     eventLoop tv xcfg [] sig
   where
-    handler thing (SomeException _) =
-      void $ putStrLn ("Thread " ++ thing ++ " failed")
+    handler thing (SomeException e) =
+      void $ putStrLn ("Thread " ++ thing ++ " failed: " ++ show e)
     -- Reacts on events from X
     eventer signal =
       allocaXEvent $ \e -> do
